package Bencher::Scenarios::GetoptLongEvenLess;

our $DATE = '2016-01-08'; # DATE
our $VERSION = '0.02'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: Bencher scenarios to benchmark Getopt::Long

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::GetoptLongEvenLess - Bencher scenarios to benchmark Getopt::Long

=head1 VERSION

This document describes version 0.02 of Bencher::Scenarios::GetoptLongEvenLess (from Perl distribution Bencher-Scenarios-GetoptLongEvenLess), released on 2016-01-08.

=head1 SEE ALSO

L<Getopt::Long>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-GetoptLongEvenLess>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-GetoptLongEvenLess>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-GetoptLongEvenLess>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
